@@ -19,7 +19,7 @@ from pywss.closing import Closing
 from pywss.routing import Route
 from pywss.openapi import openapi_ui_template, merge_dict, parameters_filter
 
-__version__ = '0.1.12'
+__version__ = '0.1.13'
 
 
 class Context:
@@ -41,7 +41,7 @@ class Context:
         self.route: str = route
         self._handlers: list = handlers
         self.address: tuple = address
-        self.data: data = data()  # data save for user
+        self.data: Data = Data()  # data save for user
 
         self.content_length: int = int(headers.get("Content-Length", 0))
         self.content: bytes = b""  # default empty, use self.body() to instead
@@ -436,6 +436,8 @@ class App:
                 ctx = Context(self, request, address, log, rfd, method, path, paths, version, hes, route, handlers)
                 ctx.next()
                 ctx.flush()
+                if ctx.content_length != len(ctx.content):  # sock should be close
+                    return
         except ConnectionAbortedError:
             log.error("connect abort")
         except:
@@ -470,14 +472,14 @@ class App:
                         if not ready:
                             continue
                         request, address = sock.accept()
-                        threading.Thread(target=self._, args=(request, address)).start()
+                        threading.Thread(target=self._, args=(request, address), daemon=True).start()
             for i in range(grace):
                 self.log.update(hit=i + 1, grace=grace).warning("server closing")
                 time.sleep(1)
             self.log.warning("server closed")
 
 
-class data(dict):
+class Data(dict):
 
     def __setattr__(self, key, value):
         self[key] = value
